@@ -216,6 +216,14 @@ Q_IMPORT_PLUGIN(VtsStelPluginInterface)
 Q_IMPORT_PLUGIN(OnlineQueriesPluginInterface)
 #endif
 
+#ifdef USE_STATIC_PLUGIN_NEBULATEXTURES
+Q_IMPORT_PLUGIN(NebulaTexturesStelPluginInterface)
+#endif
+
+#ifdef USE_STATIC_PLUGIN_MOSAICCAMERA
+Q_IMPORT_PLUGIN(MosaicCameraStelPluginInterface)
+#endif
+
 // Initialize static variables
 StelApp* StelApp::singleton = Q_NULLPTR;
 qint64 StelApp::startMSecs = 0;
@@ -310,12 +318,12 @@ StelApp::~StelApp()
 	moduleMgr->unloadModule("StelVideoMgr", false);  // We need to delete it afterward
 	moduleMgr->unloadModule("StelSkyLayerMgr", false);  // We need to delete it afterward
 	moduleMgr->unloadModule("StelObjectMgr", false);// We need to delete it afterward
+	moduleMgr->unloadModule("StelSkyCultureMgr", true);// No need to delete only later!
 	StelModuleMgr* tmp = moduleMgr;
 	moduleMgr = new StelModuleMgr(); // Create a secondary instance to avoid crashes at other deinit
 	delete tmp; tmp=Q_NULLPTR;
 	delete skyImageMgr; skyImageMgr=Q_NULLPTR;
 	delete core; core=Q_NULLPTR;
-	delete skyCultureMgr; skyCultureMgr=Q_NULLPTR;
 	delete localeMgr; localeMgr=Q_NULLPTR;
 	delete audioMgr; audioMgr=Q_NULLPTR;
 	delete videoMgr; videoMgr=Q_NULLPTR;
@@ -491,7 +499,9 @@ void StelApp::init(QSettings* conf)
 	//create non-StelModule managers
 	propMgr = new StelPropertyMgr();
 	skyCultureMgr = new StelSkyCultureMgr();
-	propMgr->registerObject(skyCultureMgr);
+	skyCultureMgr->init();
+	getModuleMgr().registerModule(skyCultureMgr);
+
 	planetLocationMgr = new StelLocationMgr();
 	actionMgr = new StelActionMgr();
 
@@ -573,6 +583,9 @@ void StelApp::init(QSettings* conf)
 	if (audioOK)
 		SplashScreen::showMessage(q_("Initializing audio..."));
 	audioMgr = new StelAudioMgr(audioOK);
+	// QtMultimedia can create and destroy intermediate contexts during initialization,
+	// displacing our main context, see GH#4143. So restore our context.
+	ensureGLContextCurrent();
 
 	// Init video manager
 #ifdef ENABLE_MEDIA
@@ -1042,7 +1055,6 @@ void StelApp::highGraphicsModeDraw()
 		const auto rgbMaxValue=calcRGBMaxValue(core->getDitheringMode());
 		postProcessorProgram->setUniformValue(postProcessorUniformLocations.rgbMaxValue,
 		                                      rgbMaxValue[0], rgbMaxValue[1], rgbMaxValue[2]);
-
 	}
 
 	postProcessorVAO->bind();
