@@ -41,9 +41,6 @@ public:
 	StelTextureSP allsky; // allsky low res version of the texture.
 	StelTextureSP normalAllsky; // allsky low res version of the texture.
 	StelTextureSP horizonAllsky; // allsky low res version of the texture.
-
-	// Used for smooth fade in
-	QTimeLine texFader;
 };
 
 static QString getExt(const QString& format)
@@ -53,6 +50,8 @@ static QString getExt(const QString& format)
 		if (ext == "jpeg") return "jpg";
 		if (ext == "png") return "png";
 		if (ext == "webp") return "webp";
+		if (ext == "tiff") return "tiff";
+		if (ext == "bmp") return "bmp";
 	}
 	return QString();
 }
@@ -67,7 +66,8 @@ QUrl HipsSurvey::getUrlFor(const QString& path) const
 	return QString("%1/%2%3").arg(base.url(), path, args);
 }
 
-HipsSurvey::HipsSurvey(const QString& url_, const QString& frame, const QString& type, double releaseDate_):
+HipsSurvey::HipsSurvey(const QString& url_, const QString& frame, const QString& type,
+                       const QMap<QString, QString>& hipslistProps, const double releaseDate_) :
 	url(url_),
 	type(type),
 	hipsFrame(frame),
@@ -77,7 +77,12 @@ HipsSurvey::HipsSurvey(const QString& url_, const QString& frame, const QString&
 	nbVisibleTiles(0),
 	nbLoadedTiles(0)
 {
-	// Immediately download the properties.
+	// First save properties from hipslist
+	for (auto it = hipslistProps.begin(); it != hipslistProps.end(); ++it)
+		properties[it.key()] = it.value();
+	checkForPlanetarySurvey();
+
+	// Immediately download the properties and replace the hipslist data with them.
 	QNetworkRequest req = QNetworkRequest(getUrlFor("properties"));
 	req.setAttribute(QNetworkRequest::CacheLoadControlAttribute, QNetworkRequest::PreferCache);
 	req.setRawHeader("User-Agent", StelUtils::getUserAgentString().toLatin1());
@@ -105,13 +110,7 @@ HipsSurvey::HipsSurvey(const QString& url_, const QString& frame, const QString&
 		if (properties.contains("hips_frame"))
 			hipsFrame = properties["hips_frame"].toString().toLower();
 
-		QStringList DSSSurveys;
-		DSSSurveys << "equatorial" << "galactic" << "ecliptic"; // HiPS frames for DSS surveys
-		if (DSSSurveys.contains(hipsFrame, Qt::CaseInsensitive) && !(properties["creator_did"].toString().contains("moon", Qt::CaseInsensitive)) && !(properties["client_category"].toString().contains("solar system", Qt::CaseInsensitive)))
-			planetarySurvey = false;
-		else
-			planetarySurvey = true;
-
+		checkForPlanetarySurvey();
 		emit propertiesChanged();
 		emit statusChanged();
 		networkReply->deleteLater();
@@ -122,6 +121,13 @@ HipsSurvey::~HipsSurvey()
 {
 }
 
+void HipsSurvey::checkForPlanetarySurvey()
+{
+	planetarySurvey = !QStringList{"equatorial","galactic","ecliptic"}.contains(hipsFrame, Qt::CaseInsensitive) ||
+	                  std::as_const(properties)["creator_did"].toString().contains("moon", Qt::CaseInsensitive) ||
+	                  std::as_const(properties)["client_category"].toString().contains("solar system", Qt::CaseInsensitive);
+}
+
 bool HipsSurvey::isVisible() const
 {
 	return static_cast<bool>(fader);
@@ -180,10 +186,16 @@ bool HipsSurvey::getAllsky()
 	}
 	if (networkReply->isFinished())
 	{
+		updateProgressBar(100, 100);
 		if (networkReply->error() == QNetworkReply::NoError) {
-			qDebug() << "got allsky";
 			QByteArray data = networkReply->readAll();
+			qDebug().nospace() << "Got allsky for " << getTitle() << ", " << data.size() << " bytes";
 			allsky = QImage::fromData(data);
+			if (allsky.isNull())
+			{
+				qWarning() << "Failed to decode allsky image data";
+				noAllsky = true;
+			}
 		} else {
 			noAllsky = true;
 		}
@@ -422,17 +434,62 @@ static bool isClipped(int n, double (*pos)[4])
     return false;
 }
 
-
-void HipsSurvey::drawTile(int order, int pix, int drawOrder, int splitOrder, bool outside,
-                          const SphericalCap& viewportShape, StelPainter* sPainter, Vec3d observerVelocity, DrawCallback callback)
+bool HipsSurvey::bindTextures(HipsTile& tile, const int orderMin, Vec2f& texCoordShift, float& texCoordScale, bool& tileIsLoaded)
 {
 	constexpr int colorTexUnit = 0;
 	constexpr int normalTexUnit = 2;
 	constexpr int horizonTexUnit = 4;
 
+	if (normals && !tile.normalTexture && !tile.normalAllsky) return false;
+	if (horizons && !tile.horizonTexture && !tile.horizonAllsky) return false;
+
+	bool ok = tile.texture->bind(colorTexUnit);
+	if (!ok) ok = tile.allsky && tile.allsky->bind(colorTexUnit);
+	if (ok && normals)
+	{
+		ok = tile.normalTexture && tile.normalTexture->bind(normalTexUnit);
+		if (!ok) ok = tile.normalAllsky && tile.normalAllsky->bind(normalTexUnit);
+	}
+	if (ok && horizons)
+	{
+		ok = tile.horizonTexture && tile.horizonTexture->bind(horizonTexUnit);
+		if (!ok) ok = tile.horizonAllsky && tile.horizonAllsky->bind(horizonTexUnit);
+	}
+
+	if (!ok) tileIsLoaded = false;
+
+	if (!ok && tile.order > orderMin)
+	{
+		// Current-level textures failed to bind, let's try the previous level
+		const auto parentTile = getTile(tile.order - 1, tile.pix / 4);
+		if (!parentTile) return false;
+		assert(parentTile->order == tile.order - 1);
+		assert(parentTile->order >= orderMin);
+
+		static const Vec2f bottomLeftPartUV[] = {Vec2f(0,0.5), Vec2f(0,0), Vec2f(0.5,0.5), Vec2f(0.5,0)};
+		const int pos = tile.pix % 4;
+		// Like the multiplication of the texture transform by scale and shift matrix on the left:
+		// transform = shift(bottomLeftPartUV[pos]) * scale(0.5) * transform
+		texCoordShift = texCoordShift * 0.5f + bottomLeftPartUV[pos];
+		texCoordScale *= 0.5f;
+
+		ok = bindTextures(*parentTile, orderMin, texCoordShift, texCoordScale, tileIsLoaded);
+		if (!ok) return false;
+	}
+
+	return ok;
+}
+
+void HipsSurvey::drawTile(int order, int pix, int drawOrder, int splitOrder, bool outside,
+                          const SphericalCap& viewportShape, StelPainter* sPainter,
+                          Vec3d observerVelocity, DrawCallback callback)
+{
 	Vec3d pos;
 	Mat3d mat3;
 	const Vec2d uv[4] = {Vec2d(0, 0), Vec2d(0, 1), Vec2d(1, 0), Vec2d(1, 1)};
+	bool tileLoaded = true;
+	Vec2f texCoordShift(0,0);
+	float texCoordScale = 1;
 	HipsTile *tile;
 	int orderMin = getPropertyInt("hips_order_min", 3);
 	QVector<Vec3d> vertsArray;
@@ -492,34 +549,16 @@ void HipsSurvey::drawTile(int order, int pix, int drawOrder, int splitOrder, boo
 	tile = getTile(order, pix);
 
 	if (!tile) return;
-	if (normals && !tile->normalTexture && !tile->normalAllsky) return;
-	if (horizons && !tile->horizonTexture && !tile->horizonAllsky) return;
-
-	if (!tile->texture->bind(colorTexUnit) && (!tile->allsky || !tile->allsky->bind(colorTexUnit)))
-		return;
-	if (normals && tile->normalTexture && !tile->normalTexture->bind(normalTexUnit) && (!tile->normalAllsky || !tile->normalAllsky->bind(normalTexUnit)))
-		return;
-	if (horizons && tile->horizonTexture && !tile->horizonTexture->bind(horizonTexUnit) && (!tile->horizonAllsky || !tile->horizonAllsky->bind(horizonTexUnit)))
+	if (!bindTextures(*tile, orderMin, texCoordShift, texCoordScale, tileLoaded))
 		return;
 
-	if (tile->texFader.state() == QTimeLine::NotRunning && tile->texFader.currentValue() == 0.0)
-		tile->texFader.start();
-	nbLoadedTiles++;
+	if (tileLoaded)
+		nbLoadedTiles++;
 
-	if (order < drawOrder)
-	{
-		// If all the children tiles are loaded, we can skip the parent.
-		int i;
-		for (i = 0; i < 4; i++)
-		{
-			HipsTile* child = getTile(order + 1, pix * 4 + i);
-			if (!child || child->texFader.currentValue() < 1.0) break;
-		}
-		if (i == 4) goto skip_render;
-	}
+	if (order < drawOrder) goto skip_render;
 
 	// Actually draw the tile, as a single quad.
-	alpha = color[3] * static_cast<float>(tile->texFader.currentValue());
+	alpha = color[3];
 	if (alpha < 1.0f)
 	{
 		sPainter->setBlending(true);
@@ -532,7 +571,7 @@ void HipsSurvey::drawTile(int order, int pix, int drawOrder, int splitOrder, boo
 	}
 	sPainter->setCullFace(true);
 	nb = fillArrays(order, pix, drawOrder, splitOrder, outside, sPainter, observerVelocity,
-	                vertsArray, texArray, indicesArray);
+	                texCoordShift, texCoordScale, vertsArray, texArray, indicesArray);
 	if (!callback) {
 		sPainter->setArrays(vertsArray.constData(), texArray.constData());
 		sPainter->drawFromArray(StelPainter::Triangles, nb, 0, true, indicesArray.constData());
@@ -556,6 +595,7 @@ skip_render:
 
 int HipsSurvey::fillArrays(int order, int pix, int drawOrder, int splitOrder,
                            bool outside, StelPainter* sPainter, Vec3d observerVelocity,
+                           const Vec2f& texCoordShift, const float texCoordScale,
                            QVector<Vec3d>& verts, QVector<Vec2f>& tex, QVector<uint16_t>& indices)
 {
 	Q_UNUSED(sPainter)
@@ -590,7 +630,7 @@ int HipsSurvey::fillArrays(int order, int pix, int drawOrder, int splitOrder,
 			}
 
 			verts << pos;
-			tex << texPos;
+			tex << texPos * texCoordScale + texCoordShift;
 		}
 	}
 	for (uint16_t i = 0; i < gridSize; i++)
@@ -638,37 +678,46 @@ int HipsSurvey::fillArrays(int order, int pix, int drawOrder, int splitOrder,
 QList<HipsSurveyP> HipsSurvey::parseHipslist(const QString& data)
 {
 	QList<HipsSurveyP> ret;
-	QString url;
-	QString type;
 	static const QString defaultFrame = "equatorial";
-	QString frame = defaultFrame;
-	double releaseDate = 0;
-	for (auto &line : data.split('\n'))
+	for (const auto& entry : data.split(QRegularExpression("\n\\s*\n")))
 	{
-		if (line.startsWith('#')) continue;
-		QString key = line.section("=", 0, 0).trimmed();
-		QString value = line.section("=", 1, -1).trimmed();
-		if (key == "hips_service_url") url = value;
-		// special case: https://github.com/Stellarium/stellarium/issues/1276
-		if (url.contains("data.stellarium.org/surveys/dss")) continue;
-		if (key == "hips_release_date")
+		QString url;
+		QString type;
+		QString frame = defaultFrame;
+		QString status;
+		double releaseDate = 0;
+		QMap<QString, QString> hipslistProps;
+		for (const auto &line : entry.split('\n'))
 		{
-			// XXX: StelUtils::getJulianDayFromISO8601String does not work
-			// without the seconds!
-			QDateTime date = QDateTime::fromString(value, Qt::ISODate);
-			date.setTimeSpec(Qt::UTC);
-			releaseDate = StelUtils::qDateTimeToJd(date);
-		}
-		if (key == "hips_frame")
-			frame = value.toLower();
-		if (key == "type")
-			type = value.toLower();
-		if (key == "hips_status" && value.split(' ').contains("public")) {
-			ret.append(HipsSurveyP(new HipsSurvey(url, frame, type, releaseDate)));
-			url = "";
-			frame = defaultFrame;
-			releaseDate = 0;
+			if (line.startsWith('#')) continue;
+			QString key = line.section("=", 0, 0).trimmed();
+			QString value = line.section("=", 1, -1).trimmed();
+
+			hipslistProps[key] = value;
+
+			if (key == "hips_service_url")
+			{
+				url = value;
+				// special case: https://github.com/Stellarium/stellarium/issues/1276
+				if (url.contains("data.stellarium.org/surveys/dss")) continue;
+			}
+			else if (key == "hips_release_date")
+			{
+				// XXX: StelUtils::getJulianDayFromISO8601String does not work
+				// without the seconds!
+				QDateTime date = QDateTime::fromString(value, Qt::ISODate);
+				date.setTimeSpec(Qt::UTC);
+				releaseDate = StelUtils::qDateTimeToJd(date);
+			}
+			else if (key == "hips_frame")
+				frame = value.toLower();
+			else if (key == "type")
+				type = value.toLower();
+			else if (key == "hips_status")
+				status = value.toLower();
 		}
+		if(status.split(' ').contains("public"))
+			ret.append(HipsSurveyP(new HipsSurvey(url, frame, type, hipslistProps, releaseDate)));
 	}
 	return ret;
 }
