@@ -156,32 +156,23 @@ void Landscape::loadCommon(const QSettings& landscapeIni, const QString& landsca
 
 	if (landscapeIni.childGroups().contains("location"))
 	{
-		if (landscapeIni.contains("location/planet"))
-			location.planetName = landscapeIni.value("location/planet").toString();
-		else
-			location.planetName = "Earth";
+		location.planetName = landscapeIni.value("location/planet", "Earth").toString();
 		// Tolerate decimal values in .ini file, but round to nearest integer
-		if (landscapeIni.contains("location/altitude"))
-			location.altitude = qRound(landscapeIni.value("location/altitude").toDouble());
-		if (landscapeIni.contains("location/latitude"))
-			location.setLatitude(static_cast<float>(StelUtils::getDecAngle(landscapeIni.value("location/latitude").toString())*M_180_PI));
-		if (landscapeIni.contains("location/longitude"))
-			location.setLongitude(static_cast<float>(StelUtils::getDecAngle(landscapeIni.value("location/longitude").toString())*M_180_PI));
+		location.altitude = qRound(landscapeIni.value("location/altitude", 0.).toDouble());
+		location.setLatitude(static_cast<float>(StelUtils::getDecAngle(landscapeIni.value("location/latitude", 0.).toString())*M_180_PI));
+		location.setLongitude(static_cast<float>(StelUtils::getDecAngle(landscapeIni.value("location/longitude", 0.).toString())*M_180_PI));
 		if (landscapeIni.contains("location/country"))
 			location.region = StelLocationMgr::pickRegionFromCountry(landscapeIni.value("location/country").toString());
 		if (landscapeIni.contains("location/state"))
 			location.state = landscapeIni.value("location/state").toString();
-		if (landscapeIni.contains("location/name"))
-			location.name = landscapeIni.value("location/name").toString();
-		else
-			location.name = name;
+		location.name = landscapeIni.value("location/name", name).toString();
 		location.landscapeKey = name;
 
 		QString tzString=landscapeIni.value("location/timezone", "").toString();
 		if (!tzString.isEmpty())
 			location.ianaTimeZone=StelLocationMgr::sanitizeTimezoneStringFromLocationDB(tzString);
 
-		auto defaultBortleIndex = landscapeIni.value("location/light_pollution", -1).toInt();
+		int defaultBortleIndex = landscapeIni.value("location/light_pollution", -1).toInt();
 		if (defaultBortleIndex<=0) defaultBortleIndex=-1; // neg. values in ini file signal "no change".
 		if (defaultBortleIndex>9) defaultBortleIndex=9; // correct bad values.
 		const auto lum = landscapeIni.value("location/light_pollution_luminance");
@@ -202,6 +193,10 @@ void Landscape::loadCommon(const QSettings& landscapeIni, const QString& landsca
 		defaultExtinctionCoefficient = landscapeIni.value("location/atmospheric_extinction_coefficient", -1.0).toDouble();
 		defaultTemperature = landscapeIni.value("location/atmospheric_temperature", -1000.0).toDouble();
 		defaultPressure = landscapeIni.value("location/atmospheric_pressure", -2.0).toDouble(); // -2=no change! [-1=computeFromAltitude]
+
+		location.role='X';
+		if (location.getLongitude() == 0. || location.getLatitude() == 0.)
+			qWarning() << "Longitude or latitude for landscape are zero. Intended?";
 	}
 
 	// Set minimal brightness for landscape
@@ -345,7 +340,6 @@ void Landscape::drawHorizonLine(StelCore* core, StelPainter& painter)
 	painter.setLineSmooth(false);
 }
 
-#include <iostream>
 const QString Landscape::getTexturePath(const QString& basename, const QString& landscapeId)
 {
 	// look in the landscape directory first, and if not found default to global textures directory
@@ -501,6 +495,8 @@ LandscapeOldStyle::LandscapeOldStyle(float _radius)
 	, drawGroundFirst(false)
 	, tanMode(false)
 	, calibrated(false)  // start with just the known entries.
+	, shaderVars()
+
 {
 	memorySize=sizeof(LandscapeOldStyle);
 }
@@ -592,7 +588,6 @@ void LandscapeOldStyle::load(const QSettings& landscapeIni, const QString& lands
 	// Init sides parameters
 	nbSide = static_cast<unsigned short>(landscapeIni.value("landscape/nbside", 0).toUInt());
 	sides = new landscapeTexCoord[static_cast<size_t>(nbSide)];
-	unsigned int texnum;
 	for (unsigned int i=0;i<nbSide;++i)
 	{
 		const QString key = QString("landscape/side%1").arg(i);                             // e.g. side0
@@ -600,7 +595,7 @@ void LandscapeOldStyle::load(const QSettings& landscapeIni, const QString& lands
 		const QStringList parameters = landscapeIni.value(key).toString().split(':');  // e.g. tex0:0:0:1:1
 		//TODO: How should be handled an invalid texture description?
 		QString textureName = parameters.value(0);                                    // tex0
-		texnum = textureName.right(textureName.length() - 3).toUInt();             // 0
+		unsigned int texnum = textureName.right(textureName.length() - 3).toUInt();             // 0
 		sides[i].tex = sideTexs[texnum];
 		sides[i].tex_illum = sideTexs[nbSide+texnum];
 		sides[i].texCoords[0] = parameters.at(1).toFloat();
@@ -1032,10 +1027,9 @@ void main(void)
 	if(!renderProgram || !renderProgram->isLinked())
 		return;
 
-	auto& gl = *QOpenGLContext::currentContext()->functions();
-
 	if (!onlyPolygon || !horizonPolygon) // Make sure to draw the regular pano when there is no polygon
 	{
+		auto& gl = *QOpenGLContext::currentContext()->functions();
 		renderProgram->bind();
 		bindVAO();
 
@@ -1548,6 +1542,7 @@ LandscapeFisheye::LandscapeFisheye(float _radius)
 	, mapTexIllum(StelTextureSP())
 	, mapImage(nullptr)
 	, texFov(360.)
+	, shaderVars()
 {
 	memorySize=sizeof(LandscapeFisheye);
 }
@@ -1705,10 +1700,9 @@ void main(void)
 	if(!renderProgram || !renderProgram->isLinked())
 		return;
 
-	auto& gl = *QOpenGLContext::currentContext()->functions();
-
 	if (!onlyPolygon || !horizonPolygon) // Make sure to draw the regular pano when there is no polygon
 	{
+		auto& gl = *QOpenGLContext::currentContext()->functions();
 		renderProgram->bind();
                 renderProgram->setUniformValue(shaderVars.brightness,
                                                 landscapeBrightness*landscapeTint[0],
@@ -1818,6 +1812,7 @@ LandscapeSpherical::LandscapeSpherical(float _radius)
 	, illumTexBottom(0.)
 	, mapImage(nullptr)
 	, bottomCapColor(-1.0f, 0.0f, 0.0f)
+	, shaderVars()
 {
 	memorySize=sizeof(LandscapeSpherical);
 }
@@ -2060,10 +2055,9 @@ void main(void)
 	if(!renderProgram || !renderProgram->isLinked())
 		return;
 
-	auto& gl = *QOpenGLContext::currentContext()->functions();
-
 	if (!onlyPolygon || !horizonPolygon) // Make sure to draw the regular pano when there is no polygon
 	{
+		auto& gl = *QOpenGLContext::currentContext()->functions();
 		renderProgram->bind();
 		renderProgram->setUniformValue(shaderVars.bottomCapColor,
 					       landscapeBrightness*bottomCapColor[0],
