@@ -20,7 +20,6 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#include "StelActionMgr.hpp"
 #include "LandscapeMgr.hpp"
 #include "Landscape.hpp"
 #include "AtmospherePreetham.hpp"
@@ -56,8 +55,6 @@
 #include <QElapsedTimer>
 #include <QOpenGLPaintDevice>
 
-#include <stdexcept>
-
 namespace
 {
 constexpr char ATMOSPHERE_MODEL_CONFIG_KEY[]="landscape/atmosphere_model";
@@ -171,8 +168,8 @@ void Cardinals::draw(const StelCore* core, double latitude) const
 		const float fontSizeRatio = StelApp::getInstance().screenFontSizeRatio();
 		StelPainter sPainter(prj);
 		sPainter.setFont(font4WCR);
-		float sshift=0.f, bshift=0.f, cshift=0.f, dshift=0.f, vshift=1.f;
-		bool flagMask = (core->getProjection(StelCore::FrameJ2000)->getMaskType() != StelProjector::MaskDisk);
+		const bool flagMask = (core->getProjection(StelCore::FrameJ2000)->getMaskType() != StelProjector::MaskDisk);
+		float vshift=1.f;
 		if (propMgr->getProperty("SpecialMarkersMgr.compassMarksDisplayed")->getValue().toBool())
 			vshift = static_cast<float>(screenFontSize + 12*fontSizeRatio)*ppx;
 
@@ -185,8 +182,7 @@ void Cardinals::draw(const StelCore* core, double latitude) const
 			it4w.next();
 			QString directionLabel = labels.value(it4w.key(), "");
 
-			if (flagMask)
-				sshift = ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f;
+			const float sshift = (flagMask ? ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f : 0.0f);
 
 			if (prj->project(it4w.value(), xy))
 			{
@@ -211,9 +207,7 @@ void Cardinals::draw(const StelCore* core, double latitude) const
 			{
 				it8w.next();
 				QString directionLabel = labels.value(it8w.key(), "");
-
-				if (flagMask)
-					bshift = ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f;
+				const float bshift = (flagMask ? ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f : 0.0f);
 
 				if (prj->project(it8w.value(), xy))
 				{
@@ -238,8 +232,7 @@ void Cardinals::draw(const StelCore* core, double latitude) const
 					it16w.next();
 					QString directionLabel = labels.value(it16w.key(), "");
 
-					if (flagMask)
-						cshift = ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f;
+					const float cshift = (flagMask ? ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f : 0.0f);
 
 					if (prj->project(it16w.value(), xy))
 					{
@@ -264,8 +257,7 @@ void Cardinals::draw(const StelCore* core, double latitude) const
 						it32w.next();
 						QString directionLabel = labels.value(it32w.key(), "");
 
-						if (flagMask)
-							dshift = ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f;
+						const float dshift = (flagMask ? ppx*static_cast<float>(sPainter.getFontMetrics().boundingRect(directionLabel).width())*0.5f : 0.0f);
 
 						if (prj->project(it32w.value(), xy))
 						{
@@ -1011,7 +1003,7 @@ bool LandscapeMgr::setCurrentLandscapeID(const QString& id, const double changeL
 		{
 			drawer->setAtmospherePressure(landscape->getDefaultAtmosphericPressure());
 		}
-		else if (landscape->getDefaultAtmosphericPressure() < 0.0)
+		else if (landscape->getDefaultAtmosphericPressure() < 0.0 && landscape->getDefaultAtmosphericPressure() > -1.5)
 		{
 			// compute standard pressure for standard atmosphere in given altitude if landscape.ini coded as atmospheric_pressure=-1
 			// International altitude formula found in Wikipedia.
