@@ -287,9 +287,10 @@ void StelMainScriptAPI::setObserverLocation(const QString &id, double duration)
 {
 	StelCore* core = StelApp::getInstance().getCore();
 	StelLocation loc = StelApp::getInstance().getLocationMgr().locationForString(id);
-	if (!loc.isValid())
-		return;	// location find failed
-	core->moveObserverTo(loc, duration);
+	if (loc.isValid())
+		core->moveObserverTo(loc, duration);
+	else
+		qWarning() << "core.setObserverLocation: location" << id << "invalid, not changing location:" << loc.serializeToLine();
 }
 
 QString StelMainScriptAPI::getObserverLocation()
@@ -1204,9 +1205,9 @@ void StelMainScriptAPI::clear(const QString& state)
 		StelPropertyMgr* propMgr = StelApp::getInstance().getStelPropertyManager();
 
 		// Hide artificial satellites through StelProperties to avoid crash if plugin was not loaded
-		propMgr->setStelPropertyValue("Satellites.flagHintsVisible",   false);
-		propMgr->setStelPropertyValue("Satellites.flagLabelsVisible",  false);
-		propMgr->setStelPropertyValue("Satellites.flagOrbitLines", false);
+		propMgr->setStelPropertyValue("Satellites.flagHintsVisible",   false, true);
+		propMgr->setStelPropertyValue("Satellites.flagLabelsVisible",  false, true);
+		propMgr->setStelPropertyValue("Satellites.flagOrbitLines", false, true);
 
 		// identical for all states
 		glmgr->setFlagAllGrids(false);
